function dx = ForceBalance(x1,x2,theta,x1d,x2d,thetad,I1,I2)
%DYNAMIC NON-LINEAR MODEL of the SEESAW
%Obtained throughout the force-torque balance

%STATE
% x = [x1 x2 theta x1d x2d thetad]
%CONTROL VARIABLES
% u = [I1 I2]
%OUTPUT
% x, state space

%read parameters from the workspace
global g m1 m2 r1 r2 Cu1 Cu2 

%motor force
FM1 = Cu1*I1;
FM2 = Cu2*I2;

%generalised friction (motor+cart)
FF1 = r1*x1d;
FF2 = r2*x2d;

%equation of motion
d(1)=(FM1+m1*g*sin(theta)-FF1)/m1;
d(2)=(FM2+m2*g*sin(theta)-FF2)/m2;
d(3)=0;

%output the new state
dx(1)=d(1);
dx(2)=d(2);
dx(3)=d(3);

%additional outputs
dx(4)=FF1;
dx(5)=FF2;

end

