%clear all
close all
clc

%% load global parameters
global g m1 m2 Ms Js hs h len r1 r2 mu3 Cu1 Cu2 thetamax xDmax
global x10 x20 theta0 x1d0 x2d0 thetad0
global I1_min I2_min

g = 9.81;
m1 = 0.696;         %[Kg]
m2 = 0.690;         %[Kg]
Ms = 4.872;         %[Kg]
Js = 0.8;           %[Kg*m^2]
h = 0.12;           %[m]
hs = 0.077;         %[m]
a = 0.129;          %length cart [m]
b = 0.069;          %width cart [m]
c = 0.045;          %heigth cart [m]
l_seesaw = 0.94;    %length of the seesaw [m]
len = 0.47;         %maximum displacement of the two carts [m]
thetamax = 15;      %max theta angle [deg]
xDmax = 5;          %max velocity of the carts [m/s]

I_max=4.8;          %[A]

%friction parameters
r1 = 2.32;          %[N/m/s]
r2 = 3;             %[N/m/s]
mu3 = 0.4;          %[N/rad/s]

%motor parameters
Cu1 = 3.944;        %[N/A]
Cu2 = 5.7;          %[N/A]

%static friction condition
I1_min = 0.22;      %[A]
I2_min = 0.22;      %[A]

%initial state of the seesaw
% x = [x1 x2 theta x1d x2d thetad]
% x1 = [-0.47,+0.47]
% x2 = [-0.47,+0.47]
% theta = [-degtorad(15),+degtorad(15)]
x10 = 0;            %[m]
x20 = 0;            %[m]
theta0=degtorad(0); %[rad]
x1d0 = 0;           %[m/s]
x2d0 = 0;           %[m/s]
thetad0 = 0;        %[rad/s]

%build reference signal
time=               [0	1   1.01    2.99    3       5.99    6       8.99    9       11.99   12    15.99   16  17];
refControllerTest=  [0  0   0.2     0.2     -0.1    -0.1    0.25    0.25    -0.2    -0.2    0.1   0.1     0   0];


%% run the simulation

%destructure the controller zpk structure so that it can be used in
%Simulink
if exist('C','var')
    gC = C.k;
    zC = cell2mat(C.z);
    pC = cell2mat(C.p);
else
    disp('Controller not loaded in the workspace: export it from SISOTOOL before simulating. Aborting the simulation.')
    return;
end

%run the simulation
disp('Simulating...')
sim('ControllerTest_sim')
disp('End of Simulation')

%% plot results when simulation ends

f1=figure;
set(f1,'Name','ModelBased Controller - Cart 1','NumberTitle','off','units','normalized','outerposition',[0 0 1 1]);

subplot(2,1,1)
plot(ControllerTest.time,ControllerTest.signals.values(:,1),'b')
hold on
plot(time,refControllerTest,'k')
legend('x1 ControllerTest','Location','SouthWest')
title('x1')
axis([time(1) time(end) -0.5 0.5]);
grid on;

subplot(2,1,2)
hold on
plot(ControllerTest.time,ControllerTest.signals.values(:,4),'c')
plot(ControllerTest.time,I_max*ones(size(ControllerTest.time)),'r')
plot(ControllerTest.time,-I_max*ones(size(ControllerTest.time)),'r')
legend('I1 ControllerTest','Location','SouthWest')
title('I1')
grid on



